@@ -1,13 +1,11 @@
 BUILD_BIT='32bit'
 BUILD_CPU='ARMv7 Processor rev 3 (v7l)'
-BUILD_DATE='2019-03-31'
+BUILD_DATE='2019-05-09'
 BUILD_MACHINE='armv7l'
 BUILD_OS='Linux   '
-BUILD_TIME='18:33'
-BUILT_BY='builduser'
-BUILT_ON='leming'
+BUILD_TIME='22:17'
 COMPILER_VERSION='armv7l-unknown-linux-gnueabihf-gcc (GCC) 8.2.1 20181127'
-CYTHON_VERSION='0.29.6'
+CYTHON_VERSION='0.29.7'
 LINKER_VERSION='GNU ld (GNU Binutils) 2.31.1'
 PYTHON_VERSION='2.7.16'
 RELEASE_BUILD=True
